#!/bin/ash

BASE_DIRECTORY=$1          
ART_PATH=$2          
DEPLOY_PATH=$3             
AZURE_STORAGE_SAS_TOKEN=$4 
AZURE_CONTAINER_NAME=$5     
AZURE_PATH=$6

if [[ ! "${CI_JOB_NAME}" =~ "embedded" ]]; then

    echo "##################################################################"
    echo "#######################  BUNDLE FILE  ############################"
    echo "##################################################################"

    #Copy the bundle file and rename it
    find $ART_PATH -iname *"$MACHINE.raucb" -exec cp -L {} $BASE_DIRECTORY/ \;
    mv *raucb $BASE_DIRECTORY/$bundle_filename
    az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
        --sas-token $AZURE_STORAGE_SAS_TOKEN \
        --container-name $AZURE_CONTAINER_NAME \
        --file $BASE_DIRECTORY/$bundle_filename \
        --name $AZURE_PATH/$DEPLOY_PATH/$bundle_filename \
        --overwrite

    if [ ! -n "$CI_COMMIT_TAG" ]; then
        az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
            --sas-token $AZURE_STORAGE_SAS_TOKEN \
            --container-name $AZURE_CONTAINER_NAME \
            --file $BASE_DIRECTORY/$bundle_filename \
            --name $AZURE_PATH/$DEPLOY_PATH/$bundle_filename_latest \
            --overwrite
    fi
fi

case none in
*${UBOOT_FILE}*) echo "Not deploying U-Boot for this board since not present" ;;
*)
    echo "##################################################################"
    echo "########################  UBOOT  #################################"
    echo "##################################################################"

    #Compress the uboot package and create a tar.gz file
    echo $ART_PATH
    ls -la $ART_PATH
    uboot_dir="$BASE_DIRECTORY/seco-uboot"
    mkdir -p $uboot_dir

    for el in $UBOOT_FILE; do
      find $ART_PATH -iname $el -exec cp -L {} $uboot_dir/ \;
    done
    tar -czvf $BASE_DIRECTORY/$uboot_filename -C $uboot_dir $(for el in ${UBOOT_FILE}; do echo $el; done)
    ls -la

    az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
        --sas-token $AZURE_STORAGE_SAS_TOKEN \
        --container-name $AZURE_CONTAINER_NAME \
        --file $BASE_DIRECTORY/$uboot_filename \
        --name $AZURE_PATH/$DEPLOY_PATH/$uboot_filename \
        --overwrite

    if [ ! -n "$CI_COMMIT_TAG" ]; then
        az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
            --sas-token $AZURE_STORAGE_SAS_TOKEN \
            --container-name $AZURE_CONTAINER_NAME \
            --file $BASE_DIRECTORY/$uboot_filename \
            --name $AZURE_PATH/$DEPLOY_PATH/$uboot_filename_latest \
            --overwrite
    fi
    echo "Finishing U-Boot upload"
    ;;
esac

case none in
*${KERNEL_FILE}*) echo "Not deploying Kernel for this board since not present" ;;
*)
    echo "##################################################################"
    echo "########################  KERNEL  ################################"
    echo "##################################################################"

    kernel_dir="$BASE_DIRECTORY/seco-kernel-$BOARD-$PROCESSOR"
    mkdir -p $kernel_dir/boot $kernel_dir/lib

    #Find all the needed kernel packages and copy them inside the proper folders
    find $BASE_DIRECTORY/$ART_PATH -iname $KERNEL_FILE \
        -exec cp -L {} $kernel_dir/boot \;
    find $BASE_DIRECTORY/$ART_PATH -maxdepth 2 -iname *.dtb \
        -exec cp -L {} $kernel_dir/boot \;
    find $BASE_DIRECTORY/$ART_PATH -iname *.dtbo \
        -exec cp -L {} $kernel_dir/boot \;
    find $BASE_DIRECTORY/$ART_PATH -iname *fw*.bin \
        -exec cp -L {} $kernel_dir/boot \;
    find $BASE_DIRECTORY/$ART_PATH -iname modules-seco-*.tgz \
        -exec cp -L {} $BASE_DIRECTORY/temp_mod.tgz \;
    tar -xf $BASE_DIRECTORY/temp_mod.tgz -C $kernel_dir
    rm $BASE_DIRECTORY/temp_mod.tgz

    #Compress the kernel package and create a tar.gz file
    tar -czvf $BASE_DIRECTORY/$kernel_filename -C $kernel_dir boot lib
    rm -rf $kernel_dir
    az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
        --sas-token $AZURE_STORAGE_SAS_TOKEN \
        --container-name $AZURE_CONTAINER_NAME \
        --file $BASE_DIRECTORY/$kernel_filename \
        --name $AZURE_PATH/$DEPLOY_PATH/$kernel_filename \
        --overwrite

    if [ ! -n "$CI_COMMIT_TAG" ]; then
        az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
            --sas-token $AZURE_STORAGE_SAS_TOKEN \
            --container-name $AZURE_CONTAINER_NAME \
            --file $BASE_DIRECTORY/$kernel_filename \
            --name $AZURE_PATH/$DEPLOY_PATH/$kernel_filename_latest \
            --overwrite
    fi
    echo "Finishing Kernel upload"
    ;;
esac

echo "##################################################################"
echo "######################  FILESYSTEM  ##############################"
echo "##################################################################"
find $BASE_DIRECTORY/$ART_PATH -iname *."$FS_EXTENSION" \
    -exec cp -L {} $BASE_DIRECTORY/filesystemTMP.tar.bz2 \;
mv filesystemTMP.tar.bz2 $BASE_DIRECTORY/$filesystem_name
az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
    --sas-token $AZURE_STORAGE_SAS_TOKEN \
    --container-name $AZURE_CONTAINER_NAME \
    --file $BASE_DIRECTORY/$filesystem_name \
    --name $AZURE_PATH/$DEPLOY_PATH/$filesystem_name \
    --overwrite

if [ ! -n "$CI_COMMIT_TAG" ]; then
    az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
        --sas-token $AZURE_STORAGE_SAS_TOKEN \
        --container-name $AZURE_CONTAINER_NAME \
        --file $BASE_DIRECTORY/$filesystem_name \
        --name $AZURE_PATH/$DEPLOY_PATH/$filesystem_name_latest \
        --overwrite
fi

echo "################################################################"
echo "#######################  BMAP IMAGE  ###########################"
echo "################################################################"

#Copy the BMAP .wic image and rename it
find $BASE_DIRECTORY/$ART_PATH \
    -iname *rootfs."$IMAGE_EXTENSION" \
    -exec cp -L {} . \;
mv *rootfs."$IMAGE_EXTENSION" $BASE_DIRECTORY/$image_name
az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
    --sas-token $AZURE_STORAGE_SAS_TOKEN \
    --container-name $AZURE_CONTAINER_NAME \
    --file $BASE_DIRECTORY/$image_name \
    --name $AZURE_PATH/$DEPLOY_PATH/$image_name \
    --overwrite

if [ ! -n "$CI_COMMIT_TAG" ]; then
    az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
        --sas-token $AZURE_STORAGE_SAS_TOKEN \
        --container-name $AZURE_CONTAINER_NAME \
        --file $BASE_DIRECTORY/$image_name \
        --name $AZURE_PATH/$DEPLOY_PATH/$image_name_latest \
        --overwrite
fi

echo "################################################################"
echo "#######################  BMAP FILE  ############################"
echo "################################################################"

#Copy the bmap files and rename it
find $ART_PATH -iname *rootfs.wic.bmap -exec cp -L {} $BASE_DIRECTORY/ \;
mv *rootfs.wic.bmap $BASE_DIRECTORY/$bmap_name
az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
    --sas-token $AZURE_STORAGE_SAS_TOKEN \
    --container-name $AZURE_CONTAINER_NAME \
    --file $BASE_DIRECTORY/$bmap_name \
    --name $AZURE_PATH/$DEPLOY_PATH/$bmap_name \
    --overwrite

if [ ! -n "$CI_COMMIT_TAG" ]; then
    az storage blob upload --account-name $AZURE_STORAGE_ACCOUNT \
        --sas-token $AZURE_STORAGE_SAS_TOKEN \
        --container-name $AZURE_CONTAINER_NAME \
        --file $BASE_DIRECTORY/$bmap_name \
        --name $AZURE_PATH/$DEPLOY_PATH/$bmap_name_latest \
        --overwrite
fi
